<?php
/**
 * Media Feed
 * 
 * @package    Media Feed
 * @subpackage MediaFeed Main Functions
/*  Copyright (c) 2017- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

class MediaFeed {

	private $rss_apply;
	private $posts_per_rss;
	private $exclude_id;
	private $term_filter;

	/* ==================================================
	 * Construct
	 * @since	1.00
	 */
	function __construct() {

		$media_feed_options = get_option('media_feed_options');
		$this->rss_apply = $media_feed_options['apply'];
		$this->rss_text = $media_feed_options['text'];
		$this->posts_per_rss = $media_feed_options['per_rss'];
		$this->exclude_id = $media_feed_options['exclude_id'];
		$this->term_filter = $media_feed_options['term_filter'];

	}

	/* ==================================================
	* @param	none
	* @return	feed
	* @since	1.00
	*/
	function add_custom_feed() {

		if ( $this->rss_apply['media'] ) add_feed( 'media', array($this, 'load_media_create_feed') );
		if ( $this->rss_apply['image'] ) add_feed( 'image', array($this, 'load_image_create_feed') );
		if ( $this->rss_apply['audio'] ) add_feed( 'audio', array($this, 'load_audio_create_feed') );
		if ( $this->rss_apply['video'] ) add_feed( 'video', array($this, 'load_video_create_feed') );
		if ( $this->rss_apply['misc'] ) add_feed( 'misc', array($this, 'load_misc_create_feed') );

	}

	/* ==================================================
	* @param	none
	* @since	1.00
	*/
	function load_media_create_feed() {

		$attachments = $this->load_db('media');
		$this->load_create_feed('media', $attachments);

	}

	/* ==================================================
	* @param	none
	* @since	1.00
	*/
	function load_image_create_feed() {

		$attachments = $this->load_db('image');
		$this->load_create_feed('image', $attachments);

	}

	/* ==================================================
	* @param	none
	* @since	1.00
	*/
	function load_audio_create_feed() {

		$attachments = $this->load_db('audio');
		$this->load_create_feed('audio', $attachments);

	}

	/* ==================================================
	* @param	none
	* @since	1.00
	*/
	function load_video_create_feed() {

		$attachments = $this->load_db('video');
		$this->load_create_feed('video', $attachments);

	}

	/* ==================================================
	* @param	none
	* @since	1.00
	*/
	function load_misc_create_feed() {

		$attachments = $this->load_db('misc');
		$this->load_create_feed('misc', $attachments);

	}

	/* ==================================================
	* @param	$slug
	* @return	$attachments
	* @since	1.00
	*/
	function load_db($slug) {

		if ( $slug === 'media' ) {
			$mimetype = NULL;
		} else if ( $slug === 'misc' ) {
			$mimetype = "
						AND post_mime_type NOT LIKE 'image%'
						AND post_mime_type NOT LIKE 'audio%'
						AND post_mime_type NOT LIKE 'video%'
						";
		} else {
			$mimetype = "AND post_mime_type LIKE '".$slug."%'";
		}

		$notid = NULL;
		if ( !empty($this->exclude_id) ) {
			$notids = "'".implode("','", $this->exclude_id)."'";
			$notid = "AND ID NOT IN ($notids)";
		}

		if ( !empty($this->term_filter) ) {
			$term_names = "'".implode("','", $this->term_filter)."'";
			$term1 = "AND";
			$term2 = "IN ($term_names)";
		}

		$limit = $this->posts_per_rss[$slug];

		global $wpdb;
		if ( !empty($this->term_filter) ) {
			$attachments = $wpdb->get_results("
							SELECT	ID, post_date, post_title, post_mime_type
							FROM	$wpdb->posts
							LEFT JOIN $wpdb->term_relationships ON($wpdb->posts.ID = $wpdb->term_relationships.object_id)
							LEFT JOIN $wpdb->term_taxonomy ON($wpdb->term_relationships.term_taxonomy_id = $wpdb->term_taxonomy.term_taxonomy_id)
							LEFT JOIN $wpdb->terms ON($wpdb->term_taxonomy.term_id = $wpdb->terms.term_id)
							WHERE	post_type = 'attachment'
									$notid
									$mimetype
									$term1 $wpdb->terms.name $term2
									ORDER BY post_date DESC
									LIMIT $limit
							");
		} else {
			$attachments = $wpdb->get_results("
							SELECT	ID, post_date, post_title, post_mime_type
							FROM	$wpdb->posts
							WHERE	post_type = 'attachment'
									$notid
									$mimetype
									ORDER BY post_date DESC
									LIMIT $limit
							");
		}

		return $attachments;

	}

	/* ==================================================
	* @param	string	$slug
	* @param	array	$attachments
	* @since	1.00
	*/
	function load_create_feed($slug, $attachments) {

		if ( empty($attachments) ) return;

		$feed = NULL;
		foreach ( $attachments as $attachment ) {
			$feed .= $this->xml_item($slug, $attachment->ID, $attachment->post_date, $attachment->post_title, $attachment->post_mime_type);
		}

		$this->feed_main($feed, $this->rss_text[$slug]);

	}

	/* ==================================================
	* @param	$feed
	* @param	$feed_title
	* @return	$feed
	* @since	1.00
	*/
	function feed_main($feed, $feed_title) {

		$date = get_lastpostmodified( 'GMT' );
		$date = $date ? mysql2date( 'r', $date, false ) : date( 'r' );

		$duration = 'hourly';
		$update_period = apply_filters( 'rss_update_period', $duration );

		$frequency = '1';
		$update_frequency = apply_filters( 'rss_update_frequency', $frequency );

		$feed = '<?xml version="1.0" encoding="'.get_option('blog_charset').'"?'.'>'."\n".
				'<rss version="2.0"'."\n".
				'	xmlns:content="http://purl.org/rss/1.0/modules/content/"'."\n".
				'	xmlns:wfw="http://wellformedweb.org/CommentAPI/"'."\n".
				'	xmlns:dc="http://purl.org/dc/elements/1.1/"'."\n".
				'	xmlns:atom="http://www.w3.org/2005/Atom"'."\n".
				'	xmlns:sy="http://purl.org/rss/1.0/modules/syndication/"'."\n".
				'	xmlns:slash="http://purl.org/rss/1.0/modules/slash/"'."\n".
				'>'."\n".
				'<channel>'."\n".
				'	<title>'.$feed_title.' &#187; '.get_bloginfo('name').'</title>'."\n".
				'	<atom:link href="'.get_bloginfo('rss2_url').'" rel="self" type="application/rss+xml" />'."\n".
				'	<link>'.get_bloginfo('rss2_url').'</link>'."\n".
				'	<description>'.get_bloginfo('description').'</description>'."\n".
				'	<lastBuildDate>'.$date.'</lastBuildDate>'."\n".
				'	<language>'.get_bloginfo( 'language' ).'</language>'."\n".
				'	<sy:updatePeriod>'.$update_period.'</sy:updatePeriod>'."\n".
				'	<sy:updateFrequency>'.$update_frequency.'</sy:updateFrequency>'."\n".
				$feed.
				'</channel>'."\n".
				'</rss>';

		header('Content-Type: ' . feed_content_type('rss2') . '; charset=' . get_option('blog_charset'), true);
		echo $feed;

	}

	/* ==================================================
	* @param	string	$type
	* @param	int		$pid
	* @param	string	$datetime
	* @param	string	$title
	* @param	string	$mime_type
	* @return	string	$xmlitem
	* @since	1.00
	*/
	function xml_item($type, $pid, $datetime, $title, $mime_type) {

		$link_url = wp_get_attachment_url($pid);

		$attachment_metadata = array();
		$attachment_metadata = get_post_meta($pid, '_wp_attachment_metadata', TRUE);
		if ( isset( $attachment_metadata['filesize'] ) ) {
			$file_size = $attachment_metadata['filesize'];
		} else {
			$file_size = filesize(get_attached_file($pid));
		}
		if ( $type === 'media' ) {
			$filetype = wp_check_filetype(get_attached_file($pid));
			$type = wp_ext2type($filetype['ext']);
			if ( $type <> 'image' && $type <> 'audio' && $type <> 'video' ) {
				$type = 'misc';
			}
		}
		unset($attachment_metadata);

		$thumblink = NULL;
		if ( $type === 'image' ){
			$thumb_src = wp_get_attachment_image_src($pid, 'thumbnail', FALSE);
		} else {
			$thumb_src = wp_get_attachment_image_src($pid, 'thumbnail', TRUE);
		}
		$thumblink = $thumb_src[0];
		unset($thumb_src);

		$xmlitem = NULL;
		$xmlitem .= "<item>\n";
		$xmlitem .= "<title>".$title."</title>\n";
		$xmlitem .= "<link>".$link_url."</link>\n";
		if ( $type === 'audio' || $type === 'video' ){
			$xmlitem .= '<enclosure url="'.$link_url.'" length="'.$file_size.'" type="'.$mime_type.'" />'."\n";
		}
		if( !empty($thumblink) ) {
			$img_url = '<a href="'.$link_url.'"><img src = "'.$thumblink.'"></a>';
			$xmlitem .= "<description><![CDATA[".$img_url."]]></description>\n";
		}
		$xmlitem .= "<pubDate>".mysql2date( DATE_RSS, $datetime )."</pubDate>\n";
		$xmlitem .= "</item>\n";

		return $xmlitem;

	}

	/* ==================================================
	* @param	string	$type
	* @param	int		$pid
	* @param	string	$datetime
	* @param	string	$title
	* @param	string	$mime_type
	* @return	string	$listitem
	* @since	1.00
	*/
	function list_item($type, $pid, $datetime, $title, $mime_type) {

		$link_url = wp_get_attachment_url($pid);

		$attachment_metadata = array();
		$attachment_metadata = get_post_meta($pid, '_wp_attachment_metadata', TRUE);
		if ( isset( $attachment_metadata['filesize'] ) ) {
			$file_size = $attachment_metadata['filesize'];
		} else {
			$file_size = filesize(get_attached_file($pid));
		}
		unset($attachment_metadata);

		$thumblink = NULL;
		if ( $type === 'image' ){
			$thumb_src = wp_get_attachment_image_src($pid, 'thumbnail', FALSE);
		} else {
			$thumb_src = wp_get_attachment_image_src($pid, 'thumbnail', TRUE);
		}
		$thumblink = $thumb_src[0];
		unset($thumb_src);

		$listitem = NULL;
		if( !empty($thumblink) ) {
			$listitem = '<div style="padding: 10px 10px;"><a style="text-decoration: none;" href="'.$link_url.'"><img style="float: left; margin-right:10px;" src = "'.$thumblink.'">'.'<div>'.$title.'</div></a><div>['.$datetime.'] ['.size_format($file_size, 2).'] ['.$mime_type.']</div></div><div style="clear: both;"></div>';
		}

		return $listitem;

	}

	/* ==================================================
	* @param	none
	* @return	alternate link
	* @since	1.00
	*/
	function mediafeed_alternate() {

		if ( $this->rss_apply['media'] ) echo '<link rel="alternate" type="'.feed_content_type(). '" title="'.esc_attr($this->rss_text['media']).' '.__('Feed', 'media-feed').' &raquo; '.esc_attr(get_bloginfo('name')).'" href="' . get_feed_link('media'). "\" />\n";
		if ( $this->rss_apply['image'] ) echo '<link rel="alternate" type="'.feed_content_type(). '" title="'.esc_attr($this->rss_text['image']).' '.__('Feed', 'media-feed').' &raquo; '.esc_attr(get_bloginfo('name')).'" href="' . get_feed_link('image'). "\" />\n";
		if ( $this->rss_apply['audio'] ) echo '<link rel="alternate" type="'.feed_content_type(). '" title="'.esc_attr($this->rss_text['audio']).' '.__('Feed', 'media-feed').' &raquo; '.esc_attr(get_bloginfo('name')).'" href="' . get_feed_link('audio'). "\" />\n";
		if ( $this->rss_apply['video'] ) echo '<link rel="alternate" type="'.feed_content_type(). '" title="'.esc_attr($this->rss_text['video']).' '.__('Feed', 'media-feed').' &raquo; '.esc_attr(get_bloginfo('name')).'" href="' . get_feed_link('video'). "\" />\n";
		if ( $this->rss_apply['misc'] ) echo '<link rel="alternate" type="'.feed_content_type(). '" title="'.esc_attr($this->rss_text['misc']).' '.__('Feed', 'media-feed').' &raquo; '.esc_attr(get_bloginfo('name')).'" href="' . get_feed_link('misc'). "\" />\n";

	}

	/* ==================================================
	 * short code
	 * @param	array	$atts
	 * @return	string	$html
	 */
	function mediafeedlist_func( $atts, $html = NULL ) {

		extract(shortcode_atts(array(
			'slug' => ''
		), $atts));

		$attachments = $this->load_db($slug);

		if ( empty($attachments) ) return $html;

		$feedtitle = $this->rss_text[$slug];

		$ids = NULL;
		$listitem_media_misc = NULL;
		foreach ( $attachments as $attachment ) {
			// for image,audio,video
			$ids .= $attachment->ID.',';

			// for media,misc
			$listitem_media_misc .= $this->list_item($slug, $attachment->ID, $attachment->post_date, $attachment->post_title, $attachment->post_mime_type);

		}
		$ids = rtrim($ids, ',');

		$list = NULL;
		if ( $slug === 'audio' || $slug === 'video' ) {
			if ( !empty($ids) ) {
				$shortcode = '[playlist type="'.$slug.'" ids="'.$ids.'"]';
				$list = do_shortcode($shortcode);
			}
		} else if ( $slug === 'image' ) {
			if ( !empty($ids) ) {
				$shortcode = '[gallery include="'.$ids.'"]';
				$list = do_shortcode($shortcode);
			}
		} else {
			$list = $listitem_media_misc;
		}

		$iconlink = NULL;
		$feedwidget_tbl = get_option( 'media_feed_widget' );
		if ( $this->rss_apply[$slug] ) {
			$iconlink = '<div align="right"><a href="'.$feedwidget_tbl[$slug].'" style="text-decoration: none; word-break: break-all;" title="'.esc_attr($feedtitle).'"><span class="dashicons dashicons-rss"></span>'.$feedtitle.'</a></div>';
		}

		$html = $list.$iconlink;

		return $html;

	}

}

?>