<?php
/**
 * Media Feed
 * 
 * @package    Media Feed
 * @subpackage MediaFeedAdmin Management screen
    Copyright (c) 2017- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

class MediaFeedAdmin {

	/* ==================================================
	 * Add a "Settings" link to the plugins page
	 * @since	1.0
	 */
	function settings_link($links, $file) {
		static $this_plugin;
		if ( empty($this_plugin) ) {
			$this_plugin = MEDIAFEED_PLUGIN_BASE_FILE;
		}
		if ( $file == $this_plugin ) {
			$links[] = '<a href="'.admin_url('options-general.php?page=MediaFeed').'">'.__( 'Settings').'</a>';
		}
		return $links;
	}

	/* ==================================================
	 * Settings page
	 * @since	1.0
	 */
	function plugin_menu() {
		add_options_page( 'MediaFeed Options', 'Media Feed', 'manage_options', 'MediaFeed', array($this, 'plugin_options') );
	}

	/* ==================================================
	 * Add Css and Script
	 * @since	1.00
	 */
	function load_custom_wp_admin_style() {
		if ($this->is_my_plugin_screen()) {
			wp_enqueue_style( 'jquery-responsiveTabs', MEDIAFEED_PLUGIN_URL.'/css/responsive-tabs.css' );
			wp_enqueue_style( 'jquery-responsiveTabs-style', MEDIAFEED_PLUGIN_URL.'/css/style.css' );
			wp_enqueue_script('jquery');
			wp_enqueue_script( 'jquery-responsiveTabs', MEDIAFEED_PLUGIN_URL.'/js/jquery.responsiveTabs.min.js' );
			wp_enqueue_script( 'mediafeed-admin-js', MEDIAFEED_PLUGIN_URL.'/js/jquery.mediafeed.admin.js', array('jquery') );
		}
	}

	/* ==================================================
	 * For only admin style
	 * @since	1.00
	 */
	function is_my_plugin_screen() {
		$screen = get_current_screen();
		if (is_object($screen) && $screen->id == 'settings_page_MediaFeed') {
			return TRUE;
		} else {
			return FALSE;
		}
	}

	/* ==================================================
	 * Settings page
	 * @since	1.00
	 */
	function plugin_options() {

		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}

		if( !empty($_POST) ) {
			$post_nonce_field = 'mediafeed_tabs';
			if ( isset($_POST[$post_nonce_field]) && $_POST[$post_nonce_field] ) {
				if ( check_admin_referer( 'mediafeed_settings', $post_nonce_field ) ) {
					$this->options_updated();
				}
			}
		}

		$scriptname = admin_url('options-general.php?page=MediaFeed');

		$media_feed_options = get_option('media_feed_options');

		?>

	<div class="wrap">
	<h2>Media Feed</h2>

	<div id="mediafeed-admin-tabs">
	  <ul>
	    <li><a href="#mediafeed-admin-tabs-1"><?php _e('Settings'); ?></a></li>
		<li><a href="#mediafeed-admin-tabs-2"><?php _e('Donate to this plugin &#187;'); ?></a></li>
	  </ul>

	  <div id="mediafeed-admin-tabs-1">
		<div class="wrap">

			<form method="post" action="<?php echo $scriptname; ?>">
			<?php wp_nonce_field('mediafeed_settings', 'mediafeed_tabs'); ?>

			<h2><?php _e('Settings'); ?></h2>	

			<div class="submit">
				<?php submit_button( __('Save Changes'), 'large', 'Submit', FALSE ); ?>
				<?php submit_button( __('Default'), 'large', 'Default', FALSE ); ?>
			</div>

			<?php
			$media_feed_link = '<a href="'.get_feed_link('media').'" target="_blank" style="text-decoration: none; word-break: break-all;">'.$media_feed_options['text']['media'].'</a>';
			$image_feed_link = '<a href="'.get_feed_link('image').'" target="_blank" style="text-decoration: none; word-break: break-all;">'.$media_feed_options['text']['image'].'</a>';
			$audio_feed_link = '<a href="'.get_feed_link('audio').'" target="_blank" style="text-decoration: none; word-break: break-all;">'.$media_feed_options['text']['audio'].'</a>';
			$video_feed_link = '<a href="'.get_feed_link('video').'" target="_blank" style="text-decoration: none; word-break: break-all;">'.$media_feed_options['text']['video'].'</a>';
			$misc_feed_link = '<a href="'.get_feed_link('misc').'" target="_blank" style="text-decoration: none; word-break: break-all;">'.$media_feed_options['text']['misc'].'</a>';
			$permlinksettings_link = '<a href="'.admin_url('options-permalink.php').'" style="text-decoration: none; word-break: break-all;">'.__('Permalink Settings').'</a>';
			?>
			<div style="width: 100%; height: 100%; margin: 5px; padding: 5px; border: #CCC 2px solid;">
				<h3><?php _e('Apply'); ?> & <?php _e('Feed name', 'media-feed'); ?> & <?php _e('Number of feeds', 'media-feed'); ?></h3>
				<div style="display: block; padding:5px 20px;">
				<table border=1 cellspacing="0" cellpadding="5" bordercolor="#000000" style="border-collapse: collapse">
				<tr><td align="center"><?php _e('Apply'); ?></td><td align="center"><?php _e('Feed', 'media-feed'); ?></td><td align="center"><?php _e('Feed name', 'media-feed'); ?></td><td align="center"><?php _e('Syndication feeds show the most recent'); ?></td></tr>
				<tr><td align="center"><input type="checkbox" name="mediafeed_apply_media" value="1" <?php checked('1', $media_feed_options['apply']['media']); ?> /></td><td align="center"><?php echo $media_feed_link; ?></td><td align="center"><input type="text" name="mediafeed_text_media" value="<?php echo $media_feed_options['text']['media']; ?>" /></td><td align="center"><input type="number" step="1" min="1" max="999" maxlength="3" class="screen-per-page" name="mediafeed_per_rss_media" value="<?php echo intval($media_feed_options['per_rss']['media']); ?>" size="3" /></td></tr>
				<tr><td align="center"><input type="checkbox" name="mediafeed_apply_image" value="1" <?php checked('1', $media_feed_options['apply']['image']); ?> /></td><td align="center"><?php echo $image_feed_link; ?></td><td align="center"><input type="text" name="mediafeed_text_image" value="<?php echo $media_feed_options['text']['image']; ?>" /></td><td align="center"><input type="number" step="1" min="1" max="999" maxlength="3" class="screen-per-page" name="mediafeed_per_rss_image" value="<?php echo intval($media_feed_options['per_rss']['image']); ?>" size="3" /></td></tr>
				<tr><td align="center"><input type="checkbox" name="mediafeed_apply_audio" value="1" <?php checked('1', $media_feed_options['apply']['audio']); ?> /></td><td align="center"><?php echo $audio_feed_link; ?></td><td align="center"><input type="text" name="mediafeed_text_audio" value="<?php echo $media_feed_options['text']['audio']; ?>" /></td><td align="center"><input type="number" step="1" min="1" max="999" maxlength="3" class="screen-per-page" name="mediafeed_per_rss_audio" value="<?php echo intval($media_feed_options['per_rss']['audio']); ?>" size="3" /></td></tr>
				<tr><td align="center"><input type="checkbox" name="mediafeed_apply_video" value="1" <?php checked('1', $media_feed_options['apply']['video']); ?> /></td><td align="center"><?php echo $video_feed_link; ?></td><td align="center"><input type="text" name="mediafeed_text_video" value="<?php echo $media_feed_options['text']['video']; ?>" /></td><td align="center"><input type="number" step="1" min="1" max="999" maxlength="3" class="screen-per-page" name="mediafeed_per_rss_video" value="<?php echo intval($media_feed_options['per_rss']['video']); ?>" size="3" /></td></tr>
				<tr><td align="center"><input type="checkbox" name="mediafeed_apply_misc" value="1" <?php checked('1', $media_feed_options['apply']['misc']); ?> /></td><td align="center"><?php echo $misc_feed_link; ?></td><td align="center"><input type="text" name="mediafeed_text_misc" value="<?php echo $media_feed_options['text']['misc']; ?>" /></td><td align="center"><input type="number" step="1" min="1" max="999" maxlength="3" class="screen-per-page" name="mediafeed_per_rss_misc" value="<?php echo intval($media_feed_options['per_rss']['misc']); ?>" size="3" /></td></tr>
				</table>
				<?php echo sprintf(__('If Feed is not displayed, save "%1$s" again.', 'media-feed'), $permlinksettings_link); ?>
				</div>
			</div>

			<div style="width: 100%; height: 100%; margin: 5px; padding: 5px; border: #CCC 2px solid;">
				<div style="display: block; padding:5px 5px;">
					<h3><?php _e('Exclude', 'media-feed'); ?> ID</h3>
					<div style="display: block; padding:5px 20px;">
					<?php _e('Specifies a comma-separated list to exclusion media ID:', 'media-feed'); ?>
					<textarea name="mediafeed_exclude_id" style="width: 100%;"><?php if(!empty($media_feed_options['exclude_id'])) echo stripslashes(implode(',', $media_feed_options['exclude_id'])); ?></textarea>
						<div>
						<?php
						$medialibrary_html = '<a href="'.admin_url( 'upload.php').'" target="_blank" style="text-decoration: none; word-break: break-all;">'.__('Media Library').'</a>';
						echo sprintf(__('When you activate this plugin, will be displayed ID is in the column of the %1$s', 'media-feed'), $medialibrary_html);
						?>
						</div>
					</div>
				</div>
			</div>

			<div style="width: 100%; height: 100%; margin: 5px; padding: 5px; border: #CCC 2px solid;">
				<div style="display: block; padding:5px 5px;">
					<h3><?php _e('Term filter list', 'media-feed'); ?></h3>
					<div style="display: block; padding:5px 20px;">
					<?php _e('Specifies a comma-separated list to filter by terms:', 'media-feed'); ?>
					<textarea name="mediafeed_term_filter" style="width: 100%;"><?php if(!empty($media_feed_options['term_filter'])) echo stripslashes(implode(',', $media_feed_options['term_filter'])); ?></textarea>
					</div>
				</div>
			</div>

			<div style="width: 100%; height: 100%; margin: 5px; padding: 5px; border: #CCC 2px solid;">
				<div style="display: block; padding:5px 5px;">
					<h3><?php _e('Shortcode', 'media-feed'); ?></h3>
					<div style="display: block; padding:5px 20px;">
					<div style="padding: 10px 0px;">
					<?php _e('Insert feed playlist and icon.', 'media-feed'); ?>
					</div>
					<h4><?php _e('Example of shortcode',  'media-feed'); ?></h4>
					<div style="padding: 10px 0px;"><code>[mediafeedlist slug="video"]</code></div>
					<div style="padding: 10px 0px;"><code>slug</code> <?php _e('Specify the slug of the following feed.', 'media-feed'); ?></div>
					<div style="padding:10px 20px;"><code>media</code> <?php _e('Media'); ?></div>
					<div style="padding:10px 20px;"><code>image</code> <?php _e('Image'); ?></div>
					<div style="padding:10px 20px;"><code>audio</code> <?php _e('Audio'); ?></div>
					<div style="padding:10px 20px;"><code>video</code> <?php _e('Video'); ?></div>
					<div style="padding:10px 20px;"><code>misc</code> <?php _e('Misc', 'media-feed'); ?></div>
					</div>
				</div>
			</div>

			<?php submit_button( __('Save Changes'), 'large', 'Submit', TRUE ); ?>

			</form>

		</div>
	  </div>

	  <div id="mediafeed-admin-tabs-2">
		<div class="wrap">
		<?php $this->credit(); ?>
		</div>
	  </div>

	</div>
	</div>
	<?php

	}

	/* ==================================================
	 * Credit
	 */
	function credit() {

		$plugin_name = NULL;
		$plugin_ver_num = NULL;
		$plugin_path = plugin_dir_path( __DIR__ );
		$plugin_dir = untrailingslashit($plugin_path);
		$slugs = explode('/', $plugin_dir);
		$slug = end($slugs);
		$files = scandir($plugin_dir);
		foreach ($files as $file) {
			if($file == '.' || $file == '..' || is_dir($plugin_path.$file)){
				continue;
			} else {
				$exts = explode('.', $file);
				$ext = strtolower(end($exts));
				if ( $ext === 'php' ) {
					$plugin_datas = get_file_data( $plugin_path.$file, array('name'=>'Plugin Name', 'version' => 'Version') );
					if ( array_key_exists( "name", $plugin_datas ) && !empty($plugin_datas['name']) && array_key_exists( "version", $plugin_datas ) && !empty($plugin_datas['version']) ) {
						$plugin_name = $plugin_datas['name'];
						$plugin_ver_num = $plugin_datas['version'];
						break;
					}
				}
			}
		}
		$plugin_version = __('Version:').' '.$plugin_ver_num;
		$faq = __('https://wordpress.org/plugins/'.$slug.'/faq', $slug);
		$support = 'https://wordpress.org/support/plugin/'.$slug;
		$review = 'https://wordpress.org/support/view/plugin-reviews/'.$slug;
		$translate = 'https://translate.wordpress.org/projects/wp-plugins/'.$slug;
		$facebook = 'https://www.facebook.com/katsushikawamori/';
		$twitter = 'https://twitter.com/dodesyo312';
		$youtube = 'https://www.youtube.com/channel/UC5zTLeyROkvZm86OgNRcb_w';
		$donate = __('https://riverforest-wp.info/donate/', $slug);

		?>
		<span style="font-weight: bold;">
		<div>
		<?php echo $plugin_version; ?> | 
		<a style="text-decoration: none;" href="<?php echo $faq; ?>" target="_blank"><?php _e('FAQ'); ?></a> | <a style="text-decoration: none;" href="<?php echo $support; ?>" target="_blank"><?php _e('Support Forums'); ?></a> | <a style="text-decoration: none;" href="<?php echo $review; ?>" target="_blank"><?php _e('Reviews', 'media-from-ftp'); ?></a>
		</div>
		<div>
		<a style="text-decoration: none;" href="<?php echo $translate; ?>" target="_blank"><?php echo sprintf(__('Translations for %s'), $plugin_name); ?></a> | <a style="text-decoration: none;" href="<?php echo $facebook; ?>" target="_blank"><span class="dashicons dashicons-facebook"></span></a> | <a style="text-decoration: none;" href="<?php echo $twitter; ?>" target="_blank"><span class="dashicons dashicons-twitter"></span></a> | <a style="text-decoration: none;" href="<?php echo $youtube; ?>" target="_blank"><span class="dashicons dashicons-video-alt3"></span></a>
		</div>
		</span>

		<div style="width: 250px; height: 180px; margin: 5px; padding: 5px; border: #CCC 2px solid;">
		<h3><?php _e('Please make a donation if you like my work or would like to further the development of this plugin.', $slug); ?></h3>
		<div style="text-align: right; margin: 5px; padding: 5px;"><span style="padding: 3px; color: #ffffff; background-color: #008000">Plugin Author</span> <span style="font-weight: bold;">Katsushi Kawamori</span></div>
		<button type="button" style="margin: 5px; padding: 5px;" onclick="window.open('<?php echo $donate; ?>')"><?php _e('Donate to this plugin &#187;'); ?></button>
		</div>

		<?php

	}

	/* ==================================================
	 * Update wp_options table.
	 * @param	none
	 * @since	1.0
	 */
	function options_updated(){

		$text_media = __('Media');
		$text_image = __('Image');
		$text_audio = __('Audio');
		$text_video = __('Video');
		$text_misc = __('Misc', 'media-feed');
		$def_per_rss = intval(get_option('posts_per_rss'));

		$media_feed_reset_options = array(
							'apply'		=> array(
											'media' => TRUE,
											'image' => TRUE,
											'audio' => TRUE,
											'video' => TRUE,
											'misc' => TRUE
											),
							'text'		=> array(
											'media' => $text_media,
											'image' => $text_image,
											'audio' => $text_audio,
											'video' => $text_video,
											'misc' => $text_misc
											),
							'per_rss'	=> array(
											'media' => $def_per_rss,
											'image' => $def_per_rss,
											'audio' => $def_per_rss,
											'video' => $def_per_rss,
											'misc' => $def_per_rss
										),
							'exclude_id' => NULL,
							'term_filter' => NULL
							);

		if ( !empty($_POST['Default']) ) {
			update_option( 'media_feed_options', $media_feed_reset_options );
			echo '<div class="notice notice-success is-dismissible"><ul><li>'.__('Settings').' --> '.__('Default').' --> '.__('Changes saved.').'</li></ul></div>';
		} else {
			if ( !empty($_POST['mediafeed_apply_media']) ) {
				$apply_media = TRUE;
			} else {
				$apply_media = FALSE;
			}
			if ( !empty($_POST['mediafeed_apply_image']) ) {
				$apply_image = TRUE;
			} else {
				$apply_image = FALSE;
			}
			if ( !empty($_POST['mediafeed_apply_audio']) ) {
				$apply_audio = TRUE;
			} else {
				$apply_audio = FALSE;
			}
			if ( !empty($_POST['mediafeed_apply_video']) ) {
				$apply_video = TRUE;
			} else {
				$apply_video = FALSE;
			}
			if ( !empty($_POST['mediafeed_apply_misc']) ) {
				$apply_misc = TRUE;
			} else {
				$apply_misc = FALSE;
			}
			if ( !empty($_POST['mediafeed_text_media']) ) $text_media = sanitize_text_field($_POST['mediafeed_text_media']);
			if ( !empty($_POST['mediafeed_text_image']) ) $text_image = sanitize_text_field($_POST['mediafeed_text_image']);
			if ( !empty($_POST['mediafeed_text_audio']) ) $text_audio = sanitize_text_field($_POST['mediafeed_text_audio']);
			if ( !empty($_POST['mediafeed_text_video']) ) $text_video = sanitize_text_field($_POST['mediafeed_text_video']);
			if ( !empty($_POST['mediafeed_text_misc']) ) $text_misc = sanitize_text_field($_POST['mediafeed_text_misc']);
			if ( !empty($_POST['mediafeed_exclude_id']) ) {
				$exclude_id = explode(',', sanitize_text_field($_POST['mediafeed_exclude_id']));
			} else {
				$exclude_id = NULL;
			}
			if ( !empty($_POST['mediafeed_term_filter']) ) {
				$term_filter = explode(',', sanitize_text_field($_POST['mediafeed_term_filter']));
			} else {
				$term_filter = NULL;
			}
			$media_feed_options = array(
								'apply'		=> array(
												'media' => $apply_media,
												'image' => $apply_image,
												'audio' => $apply_audio,
												'video' => $apply_video,
												'misc' => $apply_misc
												),
								'text'		=> array(
												'media' => $text_media,
												'image' => $text_image,
												'audio' => $text_audio,
												'video' => $text_video,
												'misc' => $text_misc
												),
								'per_rss'	=> array(
												'media' => intval($_POST['mediafeed_per_rss_media']),
												'image' => intval($_POST['mediafeed_per_rss_image']),
												'audio' => intval($_POST['mediafeed_per_rss_audio']),
												'video' => intval($_POST['mediafeed_per_rss_video']),
												'misc' => intval($_POST['mediafeed_per_rss_misc'])
											),
								'exclude_id' => $exclude_id,
								'term_filter' => $term_filter
								);

			update_option( 'media_feed_options', $media_feed_options );
			echo '<div class="notice notice-success is-dismissible"><ul><li>'.__('Settings').' --> '.__('Changes saved.').'</li></ul></div>';
		}

		return;

	}

	/* ==================================================
	 * View ID for Media Library
	 * https://gist.github.com/kachi/2208236#file-gistfile1-aw
	 * @since	1.0
	 */
	function posts_columns_attachment_id($defaults){
		$defaults['mediafeed_post_attachments_id'] = 'ID';
		return $defaults;
	}

	function posts_custom_columns_attachment_id($column_name, $id){
		if($column_name === 'mediafeed_post_attachments_id'){
			echo $id;
		}
	}

}

?>