<?php
/**
 * Media Feed
 * 
 * @package    MediaFeed
 * @subpackage MediaFeed Widget
    Copyright (c) 2017- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* ==================================================
 * Widget
 * @since	1.00
 */
class MediaFeedWidgetItem extends WP_Widget {

	private $rss_apply;

	function __construct() {

		parent::__construct(
			'MediaFeedWidgetItem', // Base ID
			'Media Feed', // Name
			array( 'description' => __( 'Entries of RSS feed from "Media Feed".', 'media-feed'), ) // Args
		);

		$media_feed_options = get_option('media_feed_options');
		$this->rss_apply = $media_feed_options['apply'];
		$this->rss_text = $media_feed_options['text'];

	}

	function widget($args, $instance) {

		extract($args);
		$title = apply_filters('widget_title', $instance['title']);
		if ($title) {
			echo $before_widget;
			echo $before_title . $title . $after_title;

			$feedwidget_tbl = get_option( 'media_feed_widget' );
			foreach ( $feedwidget_tbl as $key => $xmlurl ) {
				if ( $this->rss_apply[$key] ) {
					if ( isset($instance[$key]) && $instance[$key] ) {
						$checkbox[$key] = apply_filters('widget_checkbox', $instance[$key]);
					}
					if ( isset($checkbox[$key]) && $checkbox[$key] ) {
						$feedtitle = $this->rss_text[$key];
						?>
						<div class="textwidget"><ul><li>
						<a href="<?php echo $xmlurl; ?>" style="text-decoration: none; word-break: break-all;" title="<?php echo $feedtitle; ?>"><span class="dashicons dashicons-rss"></span><?php echo $feedtitle; ?></a>
						</li></ul></div>
						<?php
					}
				}
			}
			echo $after_widget;
		}

	}
	
	function update($new_instance, $old_instance) {

		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$feedwidget_tbl = get_option( 'media_feed_widget' );
		foreach ( $feedwidget_tbl as $key => $xmlurl ) {
			if ( $this->rss_apply[$key] ) {
				$instance[$key] = strip_tags($new_instance[$key]);
			}
		}
		return $instance;

	}
	
	function form($instance) {

		if (isset($instance['title'])) {
			$title = esc_attr($instance['title']);
		} else {
			$title = NULL;
		}
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title'); ?>:</label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
		</p>
		<table>
		<?php

		$feedwidget_tbl = get_option( 'media_feed_widget' );
		foreach ( $feedwidget_tbl as $key => $xmlurl ) {
			if ( $this->rss_apply[$key] ) {
				if (isset($instance[$key])) {
					$checkbox[$key] = esc_attr($instance[$key]);
				} else {
					$checkbox[$key] = NULL;
				}
				$feedtitle = $this->rss_text[$key];
				?>
				<tr>
				<td align="left" valign="middle" nowrap>
					<label for="<?php echo $this->get_field_id($key); ?> ">
					<input class="widefat" id="<?php echo $this->get_field_id($key); ?>" name="<?php echo $this->get_field_name($key); ?>" type="checkbox"<?php checked($key, $checkbox[$key]); ?> value="<?php echo $key; ?>" />
					<?php echo $feedtitle; ?></label>
				</td>
				</tr>
				<?php
			}
		}
		?>
		</table>
		<?php

	}

}

?>